aboutsummaryrefslogtreecommitdiff
path: root/libexec
diff options
context:
space:
mode:
authorMarcel Moolenaar <marcel@FreeBSD.org>2006-01-28 17:58:22 +0000
committerMarcel Moolenaar <marcel@FreeBSD.org>2006-01-28 17:58:22 +0000
commit05157fa0a1fbe7173f9996277a675f3caf67e75a (patch)
tree49be290141d1ee28124418436dbc410e1b5f6727 /libexec
parent4af16b88cc543ab4f1b5308be6fc39123bc1ab80 (diff)
Notes
Diffstat (limited to 'libexec')
-rw-r--r--libexec/rtld-elf/ia64/reloc.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/libexec/rtld-elf/ia64/reloc.c b/libexec/rtld-elf/ia64/reloc.c
index a45a19c40294..45f9ef54f590 100644
--- a/libexec/rtld-elf/ia64/reloc.c
+++ b/libexec/rtld-elf/ia64/reloc.c
@@ -564,7 +564,7 @@ init_pltgot(Obj_Entry *obj)
Elf_Addr *pltres = 0;
/*
* When there are no PLT relocations, the DT_IA64_PLT_RESERVE entry
* is bogus. Do not setup the BOR pointers in that case. An example
* of where this happens is /usr/lib/libxpg4.so.3.
*/
@@ -575,12 +575,12 @@ init_pltgot(Obj_Entry *obj)
* Find the PLT RESERVE section.
*/
for (dynp = obj->dynamic; dynp->d_tag != DT_NULL; dynp++) {
- if (dynp->d_tag == DT_IA64_PLT_RESERVE)
+ if (dynp->d_tag == DT_IA_64_PLT_RESERVE)
pltres = (u_int64_t *)
(obj->relocbase + dynp->d_un.d_ptr);
}
if (!pltres)
- errx(1, "Can't find DT_IA64_PLT_RESERVE entry");
+ errx(1, "Can't find DT_IA_64_PLT_RESERVE entry");
/*
* The PLT RESERVE section is used to get values to pass to
@@ -564,7 +564,7 @@ init_pltgot(Obj_Entry *obj)
Elf_Addr *pltres = 0;
/*
- * When there are no PLT relocations, the DT_IA64_PLT_RESERVE entry
+ * When there are no PLT relocations, the DT_IA_64_PLT_RESERVE entry
* is bogus. Do not setup the BOR pointers in that case. An example
* of where this happens is /usr/lib/libxpg4.so.3.